from django.conf.urls import *

from nano.blog import views

urlpatterns = patterns('',
    url(r'^(?P<year>\d{4})/(?P<month>[01]\d)/(?P<day>[0123]\d)/$', views.list_entries_by_date),
    url(r'^(?P<year>\d{4})/(?P<month>[01]\d)/$', views.list_entries_by_year_and_month),
    url(r'^(?P<year>\d{4})/$',     views.list_entries_by_year),
    url(r'^latest/$',              views.list_latest_entries),
    url(r'^today/$',               views.list_entries_for_today),
    url(r'^$',                     views.list_entries),
)



from django.conf.urls import *
from django.views.defaults import shortcut

from nano.comments.models import *

comment_dict = {}


urlpatterns = patterns('',
    url(r'^$',         views.list_comments, comment_dict, name='comments-list-comments'),
    url(r'^post$',     views.post_comment, name='comments-post-comment'),
)

urlpatterns += patterns('',
    url(r'^cr/(\d+)/(.+)/$', shortcut, name='comments-url-redirect'),
)




from django.conf.urls import *
from django.shortcuts import render

from nano.user import views

signup_done_data = {'template_name': 'nano/user/signup_done.html'}

# 'project_name' should be a setting
password_reset_data = {'project_name': 'CALS'}

urlpatterns = patterns('',
    url(r'^signup/$',           views.signup, name='nano_user_signup'),
    url(r'^password/reset/$',   views.password_reset, password_reset_data, name='nano_user_password_reset'),
    url(r'^password/change/$',  views.password_change, name='nano_user_password_change'),
)

urlpatterns += patterns('',
    url(r'^signup/done/$',      render, signup_done_data, name='nano_user_signup_done'),
)



from django.conf.urls import *

from nano.badge import views

urlpatterns = patterns('',
    url(r'^$',                 views.list_badges, name='badge-list'),
    url(r'^(?P<pk>[0-9]+)/$',  views.show_badge, name='badge-detail'),
)



"""
Wrapper for loading templates from the filesystem.
"""

from django.conf import settings
from django.db.models import get_model
from django.template.base import TemplateDoesNotExist
from django.utils._os import safe_join

# Avoid warning/exception in 1.8+
try:
    # >= Django 2.0
    from django.template.loaders.base import Loader as BaseLoader
except:
    # < Django 2.0
    from django.template.loader import BaseLoader

class Loader(BaseLoader):
    is_usable = True
    chunk_model = get_model('chunk', 'Chunk')
    chunk_model_name = self.chunk_model.__name__

    def load_template_source(self, template_name, template_dirs=None):
        template_id = (self.chunk_model_name, template_name)
        try:
            chunk = Chunk.objects.get(slug=template_name)
            return (chunk.content, "chunk:%s:%s" % template_id)
        except Chunk.DoesNotExist:
            error_msg = "Couldn't find a %s-chunk named %s" % template_id
            raise TemplateDoesNotExist(error_msg)



from django.conf.urls import *

from nano.privmsg import views

urlpatterns = patterns('',
    url(r'^add$',          views.add_pm, name='add_pm'),
    url(r'^(?P<msgid>[1-9][0-9]*)/archive$', views.move_to_archive, name='archive_pm'),
    url(r'^(?P<msgid>[1-9][0-9]*)/delete$', views.delete, name='delete_pm'),
    #url(r'^(?:(?P<action>(archive|sent))/?)?$', views.show_pms, name='show_pms'),
    url(r'^archive/$', views.show_pm_archived, name='show_archived_pms'),
    url(r'^sent/$', views.show_pm_sent, name='show_sent_pms'),
    url(r'^$', views.show_pm_received, name='show_pms'),
    #url(r'^$', views.show_pms, {u'action': u'received'}, name='show_pms'),
)

